@@ -8,23 +8,20 @@ OC.L10N.register(
     "Current" : "Huidige",
     "Completed" : "Voltooid",
     "Tasks" : "Take",
-    "Share with users or groups" : "Deel met gebruikers of groepe",
-    "No users or groups" : "Geen gebruikers of groepe",
-    "can edit" : "kan wysig",
-    "New List" : "Nuwe lys",
-    "Cancel" : "Kanselleer",
-    "Save" : "Stoor",
-    "An empty name is not allowed." : "’n Leë naam word nie toegestaan nie.",
-    "Edit" : "Wysig",
-    "Copied" : "Gekopieer",
-    "Can not copy" : "Kan nie kopieer nie",
-    "Download" : "Laai Af",
-    "Delete" : "Skrap",
-    "Unshare" : "Ontdeel",
     "Visibility of Smart Collections" : "Sigbaarheid van Slimversamelings",
     "Hidden" : "Versteek",
     "Visible" : "Sigbaar",
     "Automatic" : "Outomaties",
+    "Share with users or groups" : "Deel met gebruikers of groepe",
+    "No users or groups" : "Geen gebruikers of groepe",
+    "Edit" : "Wysig",
+    "Copied" : "Gekopieer",
+    "Download" : "Laai Af",
+    "Delete" : "Skrap",
+    "Unshare" : "Ontdeel",
+    "Cancel" : "Kanselleer",
+    "Save" : "Stoor",
+    "An empty name is not allowed." : "’n Leë naam word nie toegestaan nie.",
     "Change sort order" : "Verander sorteer volgorde",
     "Start date" : "Begindatum",
     "Due date" : "Sperdatum",
@@ -35,10 +32,11 @@ OC.L10N.register(
     "Task is completed" : "Taak is voltooid",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n Voltooide taak","%n Voltooide take"],
     "Tomorrow" : "Môre",
-    "Set start date" : "Stel begindatum",
-    "Set due date" : "Stel sperdatum",
+    "New List" : "Nuwe lys",
     "All day" : "Heeldag",
     "Task not found!" : "Taak nie gevind!",
+    "Set start date" : "Stel begindatum",
+    "Set due date" : "Stel sperdatum",
     "An error occurred" : "'n Fout het voorgekom"
 },
 "nplurals=2; plural=(n != 1);");
