@@ -8,25 +8,22 @@ OC.L10N.register(
     "Current" : "Actual",
     "Completed" : "Completado",
     "Tasks" : "Tareas",
-    "New List" : "Nueva Lista",
-    "Cancel" : "Cancelar",
-    "Save" : "Guardar",
-    "An empty name is not allowed." : "No se permite un nombre vacío.",
-    "Share with users or groups" : "Compartir con usuarios o grupos",
-    "No users or groups" : "No hay usuarios ni grupos.",
-    "can edit" : "poder editar",
-    "Unable to delete the share." : "No se puede eliminar el recurso compartido.",
-    "Unable to change permissions." : "No se pueden cambiar los permisos.",
-    "Edit" : "Editar",
-    "Copied" : "Copiado",
-    "Can not copy" : "No se puede copiar",
-    "Download" : "Descargar",
-    "Delete" : "Borrar",
-    "Unshare" : "No compartir",
     "Visibility of Smart Collections" : "Visibilidad de Colecciones Inteligentes",
     "Hidden" : "Oculto",
     "Visible" : "Visible",
     "Automatic" : "Automático",
+    "Share with users or groups" : "Compartir con usuarios o grupos",
+    "No users or groups" : "No hay usuarios ni grupos.",
+    "Unable to delete the share." : "No se puede eliminar el recurso compartido.",
+    "Unable to change permissions." : "No se pueden cambiar los permisos.",
+    "Edit" : "Editar",
+    "Copied" : "Copiado",
+    "Download" : "Descargar",
+    "Delete" : "Borrar",
+    "Unshare" : "No compartir",
+    "Cancel" : "Cancelar",
+    "Save" : "Guardar",
+    "An empty name is not allowed." : "No se permite un nombre vacío.",
     "No errors" : "Sin errores",
     "Open your browser console for more details" : "Abra la consola de su navegador para más detalles",
     "Change sort order" : "Cambiar el criterio para ordenar",
@@ -38,13 +35,14 @@ OC.L10N.register(
     "Manually" : "Manualmente",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tarea Completada","%n Tareas Completadas"],
     "Tomorrow" : "Mañana",
-    "Set start date" : "Establecer fecha de inicio",
-    "Set due date" : "Establecer fecha de vencimiento",
+    "New List" : "Nueva Lista",
     "All day" : "Todo el día",
-    "Task not found!" : "¡Tarea no encontrada!",
     "When shared show full event" : "Al compartir, mostrar el evento completo",
     "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
     "When shared hide this event" : "Al compartir, ocultar este evento ",
+    "Task not found!" : "¡Tarea no encontrada!",
+    "Set start date" : "Establecer fecha de inicio",
+    "Set due date" : "Establecer fecha de vencimiento",
     "An error occurred" : "Ocurrió un error"
 },
 "nplurals=2; plural=(n != 1);");
