@@ -8,12 +8,10 @@ OC.L10N.register(
     "Current" : "کنونی",
     "Completed" : "نکمیل شده",
     "Tasks" : "وظایف",
-    "New List" : "لیست جدید",
-    "Cancel" : "لغو",
-    "Save" : "ذخیره",
+    "Hidden" : "مخفی",
+    "Automatic" : "خودکار",
     "Share with users or groups" : "اشتراک گذاری با کاربران یا گروه ها ...",
     "No users or groups" : "هیچ کاربر یا گروهی وجود ندارد",
-    "can edit" : "توانایی ویرایش",
     "Unshare with {displayName}" : "عدم اشتراک گذاری با {displayName}",
     "Edit" : "ویرایش",
     "Copy private link" : "پیوند خصوصی را کپی کنید",
@@ -21,23 +19,23 @@ OC.L10N.register(
     "Download" : "دانلود",
     "Delete" : "حذف",
     "Unshare" : "لغو اشتراک",
+    "Cancel" : "لغو",
+    "Save" : "ذخیره",
     "Calendar link copied to clipboard." : "پیوند تقویم در کلیپ بورد کپی شد.",
     "Calendar link could not be copied to clipboard." : "پیوند تقویم را نمی توان در کلیپ بورد کپی کرد.",
     "An error occurred, unable to delete the calendar." : "خطایی روی داد ، قادر به حذف تقویم نیست.",
-    "Hidden" : "مخفی",
-    "Automatic" : "خودکار",
     "Due date" : "موعد مقرر",
     "Last modified" : "آخرین اصلاح شده",
     "Alphabetically" : "الفبایی",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n کار تکمیل شده","%n کار تکمیل شده"],
     "Tomorrow" : "فردا",
-    "Set due date" : "تعریف سر رسید",
+    "New List" : "لیست جدید",
     "All day" : "تمام روز",
-    "Add this as a new category" : "این را به عنوان یک دسته جدید اضافه کنید",
-    "Task not found!" : "کار یافت نشد!",
     "When shared show full event" : "هنگام اشتراک گذاری ، رویداد کامل را نشان می دهد",
     "When shared show only busy" : "وقتی نمایش اشتراکی فقط مشغول است",
     "When shared hide this event" : "هنگام اشتراک گذاری این رویداد را پنهان کنید",
+    "Task not found!" : "کار یافت نشد!",
+    "Set due date" : "تعریف سر رسید",
     "An error occurred" : "خطایی روی داد"
 },
 "nplurals=2; plural=(n > 1);");
