@@ -9,39 +9,37 @@ OC.L10N.register(
     "Completed" : "Valmiina",
     "Tasks" : "Tehtävät",
     "The Tasks app for Nextcloud" : "Tehtäväsovellus Nextcloudille",
-    "Add List…" : "Lisää lista…",
-    "New List" : "Uusi luettelo",
-    "Cancel" : "Peruuta",
-    "Save" : "Tallenna",
-    "The name \"{calendar}\" is already used." : "Nimi \"{calendar}\" on jo käytössä.",
-    "An empty name is not allowed." : "Nimi ei voi olla tyhjä.",
+    "Default list" : "Oletusluettelo",
+    "Visibility of Smart Collections" : "Älykkäiden kokoelmien näkyvyys",
+    "Hidden" : "Piilotettu",
+    "Visible" : "Näkyvissä",
+    "Automatic" : "Automaattinen",
     "Share with users or groups" : "Jaa käyttäjien tai ryhmien kanssa",
     "No users or groups" : "Ei käyttäjiä tai ryhmiä",
-    "can edit" : "voi muokata",
     "Unshare with {displayName}" : "Poista jako kohteesta {displayName}",
     "Unable to delete the share." : "Jakoa ei voitu poistaa.",
     "Unable to change permissions." : "Käyttöoikeuksia ei voitu muuttaa.",
     "Edit" : "Muokkaa",
     "Copy private link" : "Kopioi yksityinen linkki",
     "Copied" : "Kopioitu",
-    "Can not copy" : "Ei voida kopioida",
     "Download" : "Lataa",
     "Delete" : "Poista",
     "Unshare" : "Lopeta jakaminen",
+    "Cancel" : "Peruuta",
+    "Save" : "Tallenna",
     "Calendar link copied to clipboard." : "Kalenterilinkki kopioitu leikepöydälle.",
     "Calendar link could not be copied to clipboard." : "Kalenterilinkkiä ei voitu kopioida leikepöydälle.",
+    "The name \"{calendar}\" is already used." : "Nimi \"{calendar}\" on jo käytössä.",
+    "An empty name is not allowed." : "Nimi ei voi olla tyhjä.",
     "An error occurred, unable to delete the calendar." : "Tapahtui virhe, kalenteria ei voitu poistaa.",
     "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Poistetaan kalenteri {countdown} sekunnissa","Poistetaan kalenteri {countdown} sekunnissa"],
-    "Default list" : "Oletusluettelo",
-    "Visibility of Smart Collections" : "Älykkäiden kokoelmien näkyvyys",
-    "Hidden" : "Piilotettu",
-    "Visible" : "Näkyvissä",
-    "Automatic" : "Automaattinen",
     "Delete all completed tasks." : "Poista kaikki valmistuneet tehtävät.",
     "Delete completed tasks." : "Poista valmistuneet tehtävät.",
     "Deleted all completed tasks from calendar \"{calendar}\"." : "Poista kaikki valmistuneet tehtävät kalenterista \"{calendar}\".",
     "No errors" : "Ei virheitä",
     "Open your browser console for more details" : "Avaa selaimesi konsoli nähdäksesi lisätietoja",
+    "Add an important task to \"{calendar}\"…" : "Lisää tärkeä tehtävä kalenteriin \"{calendar}\"…",
+    "Add a task to \"{calendar}\"…" : "Lisää tehtävä kalenteriin \"{calendar}\"…",
     "Load all completed tasks." : "Lataa kaikki valmistuneet tehtävät.",
     "Change sort order" : "Muuta järjestystä",
     "Start date" : "Aloituspäivä",
@@ -55,35 +53,27 @@ OC.L10N.register(
     "Add subtask" : "Lisää alitehtävä",
     "Show subtasks" : "Näytä alitehtävät",
     "Hide subtasks" : "Piilota alitehtävät",
-    "Show completed subtasks" : "Näytä valmistuneet alitehtävät",
-    "Hide completed subtasks" : "Piilota valmistuneet alitehtävät",
     "Delete task" : "Poista tehtävä",
     "[Yesterday]" : "[Eilen]",
     "[Today]" : "[Tänään]",
     "[Tomorrow]" : "[Huomenna]",
     "Add a subtask to \"{task}\"…" : "Lisää alitehtävä tehtävään \"{task}\"…",
-    "An error occurred, unable to delete the task." : "Tapahtui virhe. Tehtävän poistaminen ei onnistunut.",
-    "Add a task to \"{task}\"…" : "Lisää tehtävä tehtävään \"{task}\"…",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n valmistunut tehtävä","%n valmistunutta tehtävää"],
-    "Add an important task to \"{calendar}\"…" : "Lisää tärkeä tehtävä kalenteriin \"{calendar}\"…",
-    "Add a task to \"{calendar}\"…" : "Lisää tehtävä kalenteriin \"{calendar}\"…",
     "Tomorrow" : "Huomenna",
-    "Set start date" : "Aseta aloituspäivä",
-    "Set start time" : "Aseta aloitusaika",
-    "Set due date" : "Aseta eräpäivä",
+    "Add List…" : "Lisää lista…",
+    "New List" : "Uusi luettelo",
     "All day" : "Koko päivä",
-    "Select a calendar" : "Valitse kalenteri",
     "Select a status" : "Valitse tila",
-    "Select categories" : "Valitse luokat",
-    "Add this as a new category" : "Lisää tämä uutena luokkana",
-    "Loading task from server." : "Ladataan tehtävää palvelimelta.",
-    "Task not found!" : "Tehtävää ei löytynyt!",
     "When shared show full event" : "Jaettaessa näytä koko tapahtuma",
     "When shared show only busy" : "Jaettaessa näytä vain varattuna oleminen",
     "When shared hide this event" : "Jaettuna piilota tämä tapahtuma",
     "Needs action" : "Vaatii toimenpiteitä",
     "In process" : "Käsittelyssä",
     "Canceled" : "Peruttu",
+    "Loading task from server." : "Ladataan tehtävää palvelimelta.",
+    "Task not found!" : "Tehtävää ei löytynyt!",
+    "Set start date" : "Aseta aloituspäivä",
+    "Set due date" : "Aseta eräpäivä",
     "{percent} % completed" : "{percent} % valmiina",
     "Successfully created the task." : "Tehtävä luotu onnistuneesti.",
     "Could not delete the task." : "Tehtävää ei voitu poistaa.",
