@@ -7,29 +7,28 @@ OC.L10N.register(
     "All" : "Tote",
     "Current" : "Actual",
     "Completed" : "Completate",
-    "Share with users or groups" : "Compartir con usatores o gruppos",
-    "can edit" : "pote modificar",
-    "New List" : "Nove Lista",
-    "Cancel" : "Cancellar",
-    "Save" : "Salveguardar",
-    "An empty name is not allowed." : "Un nomine vacue non es permittite.",
-    "Edit" : "Modificar",
-    "Download" : "Discargar",
-    "Delete" : "Deler",
-    "Unshare" : "Cessa de compartir",
     "Visibility of Smart Collections" : "Visibilitate de Collectiones Intelligente",
     "Hidden" : "Occultate",
     "Visible" : "Visibile",
     "Automatic" : "Automatic",
+    "Share with users or groups" : "Compartir con usatores o gruppos",
+    "Edit" : "Modificar",
+    "Download" : "Discargar",
+    "Delete" : "Deler",
+    "Unshare" : "Cessa de compartir",
+    "Cancel" : "Cancellar",
+    "Save" : "Salveguardar",
+    "An empty name is not allowed." : "Un nomine vacue non es permittite.",
     "Change sort order" : "Cambiar ordine de classification",
     "Priority" : "Prioritate",
     "Alphabetically" : "Alphabeticamente",
     "Manually" : "Manualmente",
     "Tomorrow" : "Deman",
-    "Set start date" : "Assigna le data de initio",
-    "Set due date" : "Assignar data debite",
+    "New List" : "Nove Lista",
     "When shared show full event" : "Quando compartite, monstrar evento integremente",
     "When shared show only busy" : "Quando compartite, monstrar solo si illo es occupate",
-    "When shared hide this event" : "Quando compartite, celar iste evento"
+    "When shared hide this event" : "Quando compartite, celar iste evento",
+    "Set start date" : "Assigna le data de initio",
+    "Set due date" : "Assignar data debite"
 },
 "nplurals=2; plural=(n != 1);");
