@@ -8,25 +8,34 @@ OC.L10N.register(
     "Current" : "Saat ini",
     "Completed" : "Selesai",
     "Tasks" : "Tugas",
-    "Share with users or groups" : "Bagi dengan pengguna atau grup",
-    "can edit" : "dapat menyunting",
-    "New List" : "Daftar Baru",
-    "Cancel" : "Batal",
-    "Save" : "Simpan",
-    "An empty name is not allowed." : "Nama kosong tidak diperbolehkan.",
-    "Edit" : "Sunting",
-    "Download" : "Unduh",
-    "Delete" : "Hapus",
-    "Unshare" : "Batalkan berbagi",
+    "The Tasks app for Nextcloud" : "Aplikasi Tugas untuk Nextcloud",
     "Visibility of Smart Collections" : "Visibilitas Koleksi Cerdas",
     "Hidden" : "Sembunyi",
     "Visible" : "Tampak",
     "Automatic" : "Otomatis",
+    "Share with users or groups" : "Bagi dengan pengguna atau grup",
+    "No users or groups" : "Tidak ada pengguna atau grup",
+    "Unshare with {displayName}" : "Batal berbagi dengan {displayName}",
+    "Edit" : "Sunting",
+    "Copy private link" : "Salin tautan privat",
+    "Download" : "Unduh",
+    "Delete" : "Hapus",
+    "Unshare" : "Batalkan berbagi",
+    "Cancel" : "Batal",
+    "Save" : "Simpan",
+    "Calendar link copied to clipboard." : "Tautan kalender disalin ke papan klip.",
+    "Calendar link could not be copied to clipboard." : "Tautan kalender tidak dapat disalin ke papan klip.",
+    "An empty name is not allowed." : "Nama kosong tidak diperbolehkan.",
+    "An error occurred, unable to delete the calendar." : "Terjadi galat, tidak dapat menghapus kalender.",
+    "Due date" : "Tenggat",
     "Last modified" : "Terakhir diubah",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tugas Diselesaikan"],
     "Tomorrow" : "Besok",
+    "New List" : "Daftar Baru",
+    "All day" : "Sepanjang hari",
+    "Task not found!" : "Tugas tidak ditemukan!",
     "Set start date" : "Atur tanggal mulai",
     "Set due date" : "Atur tanggal jatuh tempo",
-    "Task not found!" : "Tugas tidak ditemukan!"
+    "An error occurred" : "Terjadi kesalahan"
 },
 "nplurals=1; plural=0;");
