@@ -10,42 +10,42 @@ OC.L10N.register(
     "Tasks" : "タスク",
     "The Tasks app for Nextcloud" : "Nextcloud用のタスクアプリ",
     "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client - Thunderbird, Evolution, KDE Kontact, iCal, … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "有効にすると、Nextcloudアプリのメニューに新しいタスクメニューが表示されます。 そこからタスクの追加や削除、タイトル、説明、開始日、期限を編集して重要なタスクとしてマークすることができます。 タスクはユーザー間で共有することができます。 タスクはCalDavを使って同期することができます。 各タスクリストはNextcloudのカレンダーにリンクされており、ローカルクライアント（Thunderbird、Evolution、KDE Kontact、iCalなど）と同期するには、クライアントのリモートカレンダーとしてカレンダーを追加します。 各カレンダーのダウンロードボタンを使って、タスクをICSファイルとしてダウンロードすることができます。",
-    "Add List…" : "リストを追加…",
-    "New List" : "新規リスト",
-    "Cancel" : "キャンセル",
-    "Save" : "保存",
-    "The name \"{calendar}\" is already used." : "\"{calendar}\"の名称は既に使用されています。",
-    "An empty name is not allowed." : "件名を入力してください。",
+    "Default list" : "デフォルトリスト",
+    "Visibility of Smart Collections" : "スマートコレクションの表示",
+    "Hidden" : "隠す",
+    "Visible" : "表示する",
+    "Automatic" : "自動",
     "Share with users or groups" : "ユーザーまたはグループと共有する",
     "No users or groups" : "ユーザーまたはグループはありません",
-    "can edit" : "編集を許可",
     "Unshare with {displayName}" : "{displayName}との共有を解除",
     "Unable to delete the share." : "共有を解除できません。",
     "Unable to change permissions." : "権限を変更できません。",
     "Edit" : "編集",
     "Copy private link" : "プライベートリンクをコピー",
     "Copied" : "コピーしました",
-    "Can not copy" : "コピーできません",
     "Download" : "ダウンロード",
     "Delete" : "削除",
     "Unshare" : "共有を解除",
+    "Cancel" : "キャンセル",
+    "Save" : "保存",
     "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "カレンダー\"{calendar}\"とカレンダーに対応するすべてのイベントとタスクが削除されます。",
     "This will unshare the calendar \"{calendar}\"." : "カレンダー \"{calendar}\" の共有を解除します。",
     "Calendar link copied to clipboard." : "カレンダーリンクをクリップボードにコピー",
     "Calendar link could not be copied to clipboard." : "カレンダーリンクをクリップボードにコピーできませんでした。",
+    "The name \"{calendar}\" is already used." : "\"{calendar}\"の名称は既に使用されています。",
+    "An empty name is not allowed." : "件名を入力してください。",
     "An error occurred, unable to delete the calendar." : "エラーが発生したため、カレンダーを削除できません。",
     "_Shared with {num} entity_::_Shared with {num} entities_" : ["{num}個のエンティティと共有"],
-    "Default list" : "デフォルトリスト",
-    "Visibility of Smart Collections" : "スマートコレクションの表示",
-    "Hidden" : "隠す",
-    "Visible" : "表示する",
-    "Automatic" : "自動",
     "Delete all completed tasks." : "全ての完了したタスクを削除",
     "Delete completed tasks." : "完了したタスクを削除",
     "Deleted all completed tasks from calendar \"{calendar}\"." : "カレンダー \"{calendar}\" から完了したタスクをすべて削除しました。",
     "No errors" : "エラーはありません",
-    "Open your browser console for more details" : "詳細はブラウザコンソールを開きます",
+    "Open your browser console for more details" : "詳細はブラウザーコンソールを開きます",
     "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["{failedCount} 個のタスクが削除できませんでした"],
+    "Add an important task to \"{calendar}\"…" : "\"{calendar}\"に重要なタスクを追加する",
+    "Add a task due today to \"{calendar}\"…" : "\"{calendar}\"に今日が期限のタスクを追加する",
+    "Add a current task to \"{calendar}\"…" : "\"{calendar}\"に現在のタスクを追加する",
+    "Add a task to \"{calendar}\"…" : "\"{calendar}\"にタスクを追加する",
     "Load all completed tasks." : "完了済みタスクを読み込み",
     "Change sort order" : "並び順を変更",
     "Relevance" : "関連性",
@@ -71,53 +71,46 @@ OC.L10N.register(
     "Add subtask" : "サブタスクを追加",
     "Show subtasks" : "サブタスクを表示",
     "Hide subtasks" : "サブタスクを非表示",
-    "Show completed subtasks" : "完了したサブタスクを表示",
-    "Hide completed subtasks" : "完了したサブタスクを非表示",
     "Delete task" : "タスクを削除",
     "[Yesterday]" : "[昨日]",
     "[Today]" : "[今日]",
     "[Tomorrow]" : "[明日]",
     "Add a subtask to \"{task}\"…" : "\"{task}\"にサブタスクを追加...",
-    "Add a task to \"{task}\"…" : "\"{task}\"にタスクを追加...",
     "_%n Completed Task_::_%n Completed Tasks_" : ["完了済みタスク %n"],
-    "Add an important task to \"{calendar}\"…" : "\"{calendar}\"に重要なタスクを追加する",
-    "Add a task due today to \"{calendar}\"…" : "\"{calendar}\"に今日が期限のタスクを追加する",
-    "Add a current task to \"{calendar}\"…" : "\"{calendar}\"に現在のタスクを追加する",
-    "Add a task to \"{calendar}\"…" : "\"{calendar}\"にタスクを追加する",
     "Tomorrow" : "明日",
-    "Set start date" : "開始日を設定",
-    "Set start time" : "開始時刻を設定",
-    "Set due date" : "期限を設定",
-    "Set due time" : "期限時刻を設定",
+    "Add List…" : "リストを追加…",
+    "New List" : "新規リスト",
     "All day" : "終日",
-    "Select a calendar" : "カレンダーを選択",
     "Select a classification" : "分類を選択",
-    "Select categories" : "カテゴリを選択",
-    "Add this as a new category" : "これを新しいカテゴリーとして追加",
-    "Task not found!" : "タスクがありません！",
+    "Notes" : "ノート",
     "When shared show full event" : "共有時にすべてのイベントを表示",
     "When shared show only busy" : "共有時に実行中のみを表示",
     "When shared hide this event" : "共有時にこのイベントを隠す",
+    "Needs action" : "アクションが必要",
+    "In process" : "進行中",
     "Canceled" : "キャンセルされた",
+    "Loading task from server." : "タスクをサーバーから読み込み中。",
+    "Task not found!" : "タスクがありません！",
     "[Starts today]" : "[今日開始]",
     "[Starts tomorrow]" : "[明日開始]",
     "[Started yesterday]" : "[昨日から]",
+    "Set start date" : "開始日を設定",
     "[Due today]" : "[今日まで]",
     "[Due tomorrow]" : "[明日まで]",
     "[Was due yesterday]" : "[昨日が期限]",
-    "Last modified {date}" : "最終更新:\"{calendar}\".",
-    "Created {date}" : "作成:{date}",
-    "Completed {date}" : "完了:{date}",
-    "No priority assigned" : "優先順位が割り当てられていません",
-    "Priority {priority}: high" : "優先度{priority}:高",
-    "Priority {priority}: medium" : "優先度{priority}:中",
+    "Set due date" : "期限を設定",
     "Priority {priority}: low" : "優先度{priority}:低",
+    "Priority {priority}: medium" : "優先度{priority}:中",
+    "Priority {priority}: high" : "優先度{priority}:高",
+    "No priority assigned" : "優先順位が割り当てられていません",
     "{percent} % completed" : "{percent} %完了",
+    "Successfully created the task." : "タスクの作成に成功しました",
     "Could not delete the task." : "タスクを削除できませんでした",
     "Synchronizing to the server." : "サーバーと同期中",
     "Task successfully saved to server." : "タスクはサーバーに正常に保存されました。",
     "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "サーバー上でタスクが変更されたため、タスクを更新できませんでした。 クリックして更新してください。ローカルの変更は破棄されます。",
     "Could not update the task." : "タスクを更新できませんでした",
+    "Successfully updated the task." : "タスクのアップデートに成功しました",
     "An error occurred" : "エラーが発生しました"
 },
 "nplurals=1; plural=0;");
