@@ -8,20 +8,18 @@ OC.L10N.register(
     "Current" : "ამჟამინდელი",
     "Completed" : "დასრულებული",
     "Tasks" : "დავალებები",
-    "New List" : "ახალი სია",
-    "Cancel" : "უარყოფა",
-    "Save" : "შენახვა",
-    "An empty name is not allowed." : "ცარიელი სახელი არაა ნებადართული",
-    "Share with users or groups" : "გაზიარება მოხმარებლებთან ან ჯგუფებთან",
-    "can edit" : "შეუძლია შეცვლა",
-    "Edit" : "რედაქტირება",
-    "Download" : "ჩამოტვირთვა",
-    "Delete" : "წაშლა",
-    "Unshare" : "გაზიარების შეწყვეტა",
     "Visibility of Smart Collections" : "ჭკვიანი კოლექციების ხილვადობა",
     "Hidden" : "უჩინარი",
     "Visible" : "ჩანს",
     "Automatic" : "ავტომატური",
+    "Share with users or groups" : "გაზიარება მოხმარებლებთან ან ჯგუფებთან",
+    "Edit" : "რედაქტირება",
+    "Download" : "ჩამოტვირთვა",
+    "Delete" : "წაშლა",
+    "Unshare" : "გაზიარების შეწყვეტა",
+    "Cancel" : "უარყოფა",
+    "Save" : "შენახვა",
+    "An empty name is not allowed." : "ცარიელი სახელი არაა ნებადართული",
     "Change sort order" : "განლაგების შეცვლა",
     "Start date" : "დაწყების თარიღი",
     "Due date" : "განპირობებულია თარიღისთვის",
@@ -32,12 +30,13 @@ OC.L10N.register(
     "Task is completed" : "დავალება დასრულებულია",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n დასრულებული დავალება","%n დასრულებული დავალება"],
     "Tomorrow" : "ხვალ",
-    "Set start date" : "საწყისი დრო",
-    "Set due date" : "განპირობებულია თარიღისთვის",
+    "New List" : "ახალი სია",
     "All day" : "მთელი დღე",
-    "Task not found!" : "დაველბა ვერ იქნა ნაპოვნი!",
     "When shared show full event" : "როდესაც გაზიარებულია გამოჩნდეს სრული მოვლენა",
     "When shared show only busy" : "როდესაც გაზიარებულია გამოჩნდეს მხოლოდ დაკავებული",
-    "When shared hide this event" : "როდესაც გაზიარებულია არ გამოჩნდეს ეს მოვლენა"
+    "When shared hide this event" : "როდესაც გაზიარებულია არ გამოჩნდეს ეს მოვლენა",
+    "Task not found!" : "დაველბა ვერ იქნა ნაპოვნი!",
+    "Set start date" : "საწყისი დრო",
+    "Set due date" : "განპირობებულია თარიღისთვის"
 },
 "nplurals=2; plural=(n!=1);");
