@@ -8,26 +8,25 @@ OC.L10N.register(
     "Current" : "Aktuell",
     "Completed" : "Erfëllt",
     "Tasks" : "Tâchen",
-    "New List" : "Nei Lëscht",
-    "Cancel" : "Ofbriechen",
-    "Save" : "Späicheren",
-    "An empty name is not allowed." : "En eidelen Numm ass net erlaabt.",
+    "Hidden" : "Verstoppt",
+    "Visible" : "Visibel",
+    "Automatic" : "Automatesch",
     "Share with users or groups" : "Mat Benotzer oder Gruppen deelen",
-    "can edit" : "kann änneren",
     "Edit" : "Änneren",
     "Download" : "Eroflueden",
     "Delete" : "Läschen",
     "Unshare" : "Net méi deelen",
-    "Hidden" : "Verstoppt",
-    "Visible" : "Visibel",
-    "Automatic" : "Automatesch",
+    "Cancel" : "Ofbriechen",
+    "Save" : "Späicheren",
+    "An empty name is not allowed." : "En eidelen Numm ass net erlaabt.",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n erfëllt Aufgab","%n erfëllten Aufgaben"],
     "Tomorrow" : "Muer",
-    "Set start date" : "Setz en Ufanks Datum fest",
-    "Set due date" : "Datum setzen bis wéini et fälleg ass",
-    "Task not found!" : "Tâche konnt net fonnt ginn!",
+    "New List" : "Nei Lëscht",
     "When shared show full event" : "Wann et gedeelt gouf, dann de ganzen Evenement uweisen",
     "When shared show only busy" : "Wann et gedeelt gouf, dann nëmmen als beschäftegt uweisen",
-    "When shared hide this event" : "Wann et gedeelt gouf, dann verstopp dëst Evenement"
+    "When shared hide this event" : "Wann et gedeelt gouf, dann verstopp dëst Evenement",
+    "Task not found!" : "Tâche konnt net fonnt ginn!",
+    "Set start date" : "Setz en Ufanks Datum fest",
+    "Set due date" : "Datum setzen bis wéini et fälleg ass"
 },
 "nplurals=2; plural=(n != 1);");
