@@ -16,22 +16,37 @@ OC.L10N.register(
     "Automatic" : "Automatisk",
     "Share with users or groups" : "Del med brukere eller grupper",
     "No users or groups" : "Ingen brukere eller grupper",
+    "Can edit" : "Kan redigere",
     "Unshare with {displayName}" : "Fjern deling med {displayName}",
     "Unable to delete the share." : "Kan ikke slette delingen.",
     "Unable to change permissions." : "Kunne ikke endre rettigheter.",
     "Edit" : "Rediger",
     "Copy private link" : "Kopier privat lenke",
     "Copied" : "Kopiert",
+    "Cannot copy" : "Kan ikke kopiere",
     "Download" : "Last ned",
     "Delete" : "Slett",
     "Unshare" : "Opphev deling",
     "Cancel" : "Avbryt",
     "Save" : "Lagre",
+    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Dette sletter kalender \"{calendar}\" og alle hendelser og oppgaver i denne.",
     "Calendar link copied to clipboard." : "Lenke til kalender kopiert til utklippstavle.",
+    "List link copied to clipboard." : "Lenke kopiert til utklippstavlen.",
     "Calendar link could not be copied to clipboard." : "Lenke til kalender kunne ikke bli kopiert til utklippstavle.",
+    "List link could not be copied to clipboard." : "Lenke kunne ikke kopieres til utklippstavlen.",
     "The name \"{calendar}\" is already used." : "Navnet \"{calendar}\" er allerede i bruk.",
     "An empty name is not allowed." : "Et tomt navn er ikke tillatt.",
     "An error occurred, unable to delete the calendar." : "En feil oppstod, kan ikke slette kalenderen. ",
+    "An error occurred, unable to delete the list." : "En feil oppstod, kunne ikke slette listen.",
+    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Sletter kalenderen om {countdown} sekund","Sletter kalenderen om {countdown} sekunder"],
+    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Fjerner deling av kalenderen om {countdown} sekund","Fjerner deling av kalenderen om {countdown} sekunder"],
+    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Sletter listen om {countdown} sekund","Sletter listen om {countdown} sekunder"],
+    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Fjerner deling av listen om {countdown} sekund","Fjerner deling av listen om {countdown} sekunder"],
+    "Trash bin" : "Papirkurv",
+    "Name" : "Navn",
+    "Deleted" : "Slettet",
+    "Restore" : "Gjenoprett",
+    "Delete permanently" : "Slett permament",
     "Delete all completed tasks." : "Slett alle fullførte oppgaver.",
     "Delete completed tasks." : "Slett fullførte oppgaver.",
     "Deleted all completed tasks from calendar \"{calendar}\"." : "Slett alle fullførte oppgaver fra kalender \"{calendar}\".",
