@@ -8,23 +8,23 @@ OC.L10N.register(
     "Current" : "En aqueste moment",
     "Completed" : "Acabat",
     "Tasks" : "Prètzfaches",
-    "New List" : "Novèla lista",
-    "Cancel" : "Anullar",
-    "Save" : "Enregistrar",
-    "An empty name is not allowed." : "Un nom void es pas autorizat.",
-    "can edit" : "pòt modificar",
-    "Edit" : "Modificar",
-    "Download" : "Telecargar",
-    "Delete" : "Suprimir",
-    "Unshare" : "Partejar pas",
     "Visibility of Smart Collections" : "Visibilitat de las colleccions Smart",
     "Hidden" : "Amagat",
     "Visible" : "Visible",
     "Automatic" : "Automatic",
+    "Edit" : "Modificar",
+    "Download" : "Telecargar",
+    "Delete" : "Suprimir",
+    "Unshare" : "Partejar pas",
+    "Cancel" : "Anullar",
+    "Save" : "Enregistrar",
+    "An empty name is not allowed." : "Un nom void es pas autorizat.",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n prètzfach acabat","%n prètzfaches acabats"],
     "Tomorrow" : "Deman",
+    "New List" : "Novèla lista",
+    "Canceled" : "Anullat",
+    "Task not found!" : "Prètzfach pas trobat !",
     "Set start date" : "Especificar la data de començament",
-    "Set due date" : "Especificar la data d'escasença",
-    "Task not found!" : "Prètzfach pas trobat !"
+    "Set due date" : "Especificar la data d'escasença"
 },
 "nplurals=2; plural=(n > 1);");
