@@ -8,29 +8,28 @@ OC.L10N.register(
     "Current" : "Curent",
     "Completed" : "Terminat",
     "Tasks" : "Sarcini",
+    "Visibility of Smart Collections" : "Vizibilitatea colecțiilor inteligente",
+    "Hidden" : "Ascuns",
+    "Visible" : "Vizibil",
+    "Automatic" : "Automat",
     "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
     "No users or groups" : "Nu sunt utilizatori sau grupuri",
-    "can edit" : "poate edita",
-    "New List" : "Listă nouă",
-    "Cancel" : "Anulează",
-    "Save" : "Salvează",
-    "An empty name is not allowed." : "Un nume vid nu este permis.",
     "Edit" : "Editează",
     "Copy private link" : "Copiază link privat",
     "Download" : "Descarcă",
     "Delete" : "Șterge",
     "Unshare" : "Oprește partajarea",
-    "Visibility of Smart Collections" : "Vizibilitatea colecțiilor inteligente",
-    "Hidden" : "Ascuns",
-    "Visible" : "Vizibil",
-    "Automatic" : "Automat",
+    "Cancel" : "Anulează",
+    "Save" : "Salvează",
+    "An empty name is not allowed." : "Un nume vid nu este permis.",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n sarcină realizată","%n sarcini realizate","%n sarcini realizate"],
     "Tomorrow" : "Mâine",
-    "Set start date" : "Setează data de început",
-    "Set due date" : "Setează termenul limită",
-    "Task not found!" : "Sarcina nu a fost găsită!",
+    "New List" : "Listă nouă",
     "When shared show full event" : "Arată tot evenimentul la partajare",
     "When shared show only busy" : "Arată doar ocupat la partajare",
-    "When shared hide this event" : "Ascunde evenimentul la partajare"
+    "When shared hide this event" : "Ascunde evenimentul la partajare",
+    "Task not found!" : "Sarcina nu a fost găsită!",
+    "Set start date" : "Setează data de început",
+    "Set due date" : "Setează termenul limită"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
