@@ -8,20 +8,18 @@ OC.L10N.register(
     "Current" : "ปัจจุบัน",
     "Completed" : "เสร็จสมบูรณ์",
     "Tasks" : "งาน",
-    "New List" : "รายชื่อใหม่",
-    "Cancel" : "ยกเลิก",
-    "Save" : "บันทึก",
-    "An empty name is not allowed." : "ชื่อห้ามปล่อยว่าง",
-    "Share with users or groups" : "แชร์กับผู้ใช้หรือกลุ่ม",
-    "can edit" : "สามารถแก้ไข",
-    "Edit" : "แก้ไข",
-    "Download" : "ดาวน์โหลด",
-    "Delete" : "ลบ",
-    "Unshare" : "ยกเลิกการแชร์",
     "Visibility of Smart Collections" : "การแสดงผลของสมาร์ทคอลเลกชัน",
     "Hidden" : "ซ่อน",
     "Visible" : "มองเห็นได้",
     "Automatic" : "อัตโนมัติ",
+    "Share with users or groups" : "แชร์กับผู้ใช้หรือกลุ่ม",
+    "Edit" : "แก้ไข",
+    "Download" : "ดาวน์โหลด",
+    "Delete" : "ลบ",
+    "Unshare" : "ยกเลิกการแชร์",
+    "Cancel" : "ยกเลิก",
+    "Save" : "บันทึก",
+    "An empty name is not allowed." : "ชื่อห้ามปล่อยว่าง",
     "Change sort order" : "เปลี่ยนการเรียงลำดับ",
     "Start date" : "วันที่เริ่มต้น",
     "Due date" : "วันที่ครบกำหนด",
@@ -30,11 +28,12 @@ OC.L10N.register(
     "Manually" : "ทำด้วยตนเอง",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n งานเสร็จสมบูรณ์"],
     "Tomorrow" : "วันพรุ่งนี้",
-    "Set start date" : "วันที่เริ่มต้นการตั้งค่า",
-    "Set due date" : "ระบุวันครบกำหนด",
-    "Task not found!" : "ไม่พบงาน!",
+    "New List" : "รายชื่อใหม่",
     "When shared show full event" : "เมื่อแชร์จะแสดงกิจกรรมทั้งหมด",
     "When shared show only busy" : "เมื่อแชร์จะแสดงเฉพาะไม่ว่าง",
-    "When shared hide this event" : "เมื่อแชร์จะซ่อนกิจกรรมนี้"
+    "When shared hide this event" : "เมื่อแชร์จะซ่อนกิจกรรมนี้",
+    "Task not found!" : "ไม่พบงาน!",
+    "Set start date" : "วันที่เริ่มต้นการตั้งค่า",
+    "Set due date" : "ระบุวันครบกำหนด"
 },
 "nplurals=1; plural=0;");
