@@ -48,6 +48,17 @@ OC.L10N.register(
     "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["将在  {countdown} 秒后删除列表"],
     "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["将在  {countdown} 后取消共享这个列表"],
     "_Shared with {num} entity_::_Shared with {num} entities_" : ["与 {num} 个实体共享"],
+    "Trash bin" : "垃圾箱",
+    "Loading deleted calendars, tasks and events." : "正在加载已删除的日历、任务和事件",
+    "You do not have any deleted calendars, tasks or events." : "您没有任何已删除的日历、任务或事件。",
+    "Name" : "名称",
+    "Deleted" : "已删除",
+    "Restore" : "还原",
+    "Delete permanently" : "永久删除",
+    "Untitled item" : "未命名项",
+    "Could not load deleted calendars and objects" : "无法加载已删除的日历和对象",
+    "Could not restore calendar or event" : "无法还原日历或事件",
+    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["将于 {numDays} 后删除回收站内元素"],
     "Set date" : "设置日期",
     "Set time" : "设置时间",
     "Delete date" : "删除日期",
@@ -116,6 +127,7 @@ OC.L10N.register(
     "Add a subtask to \"{task}\"…" : "添加子任务到 \"{task}\" ...",
     "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["在 {countdown} 秒后删除任务"],
     "Create a new task" : "创建一个新任务",
+    "Task summary" : "任务概要",
     "Create task" : "创建任务",
     "Creating the new task…" : "正在创建新任务…",
     "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" 已被添加至  \"{calendar}\"",
@@ -178,6 +190,7 @@ OC.L10N.register(
     "No upcoming tasks" : "没有即将到来的任务",
     "upcoming tasks" : "即将到来的任务",
     "No tasks today" : "今天没有任务",
+    "No due date assigned" : "未分配到期日",
     "Successfully created the task." : "成功创建任务。",
     "Could not delete the task." : "无法删除任务。",
     "Synchronizing to the server." : "正在同步到服务器。",
