@@ -48,6 +48,17 @@ OC.L10N.register(
     "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["將在 {countdown} 秒後刪除清單"],
     "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["將在 {countdown} 秒後取消分享清單"],
     "_Shared with {num} entity_::_Shared with {num} entities_" : ["與 {num} 個實體分享了"],
+    "Trash bin" : "回收桶",
+    "Loading deleted calendars, tasks and events." : "加載已刪除的日曆、任務和活動。",
+    "You do not have any deleted calendars, tasks or events." : "您沒有任何已刪除的日曆、任務和活動。",
+    "Name" : "姓名",
+    "Deleted" : "已刪除",
+    "Restore" : "復原",
+    "Delete permanently" : "永久刪除",
+    "Untitled item" : "無題項目",
+    "Could not load deleted calendars and objects" : "無法加載已刪除的日曆和物件",
+    "Could not restore calendar or event" : "無法復原日曆或活動",
+    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["回收桶中的項目會在 {numDays} 天後被刪除"],
     "Set date" : "設定日期",
     "Set time" : "設定時間",
     "Delete date" : "刪除日期",
@@ -116,6 +127,7 @@ OC.L10N.register(
     "Add a subtask to \"{task}\"…" : "新增子任務到「{task}」……",
     "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["將在 {countdown} 秒後刪除任務"],
     "Create a new task" : "創建新任務",
+    "Task summary" : "任務摘要",
     "Create task" : "創建任務",
     "Creating the new task…" : "正在建立新任務...",
     "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" 已被添加至 \"{calendar}\"",
@@ -191,6 +203,11 @@ OC.L10N.register(
     "No upcoming tasks" : "沒有快將到期的任務",
     "upcoming tasks" : "接下來的任務",
     "No tasks today" : "今日沒有任務",
+    "No due date assigned" : "未指定截止日期",
+    "[Due yesterday]" : "[昨天截止]",
+    "[Due] L" : "[截止於] L",
+    "[Due yesterday at] LT" : "[截止時間為昨天] LT",
+    "[Due] L [at] LT" : "[截止於] L LT",
     "Successfully created the task." : "成功建立任務。",
     "Could not delete the task." : "無法刪除任務。",
     "Synchronizing to the server." : "與伺服器同步。",
